@@ -1,5 +1,4 @@
 from slack_sdk import WebClient
-from slack_sdk.errors import SlackApiError
 
 import logging
 
@@ -19,7 +18,7 @@ HEADER_MSGS = {
 }
 
 class Notify():
-    def __init__(self, slack_token, slack_channel, step, tenant, project, enable_slack_notifications=True):
+    def __init__(self, slack_token, slack_channel, step, tenant="", project="", enable_slack_notifications=True):
         """Initializes the slack notifier
 
         Args:
@@ -46,12 +45,14 @@ class Notify():
         )
         
     def get_title(self, step, tenant, project, msg_type):
+        tenant_string = f'[{tenant}]' if tenant else ""
+        project_string = f'[{project}]' if project else ""
         return [
             {
                 "type": "header",
                 "text": {
                     "type": "plain_text",
-                    "text": f'[{tenant}] [{project}] {step} - {HEADER_MSGS[msg_type]}',
+                    "text": f'{tenant_string} {project_string} {step} - {HEADER_MSGS[msg_type]}',
                     "emoji": True
                 }
             }
@@ -92,7 +93,7 @@ class Notify():
 
 
     def finish(self,success=False):
-        logging.log(f"[Notify:finish] Finish of [{self.STEP}]")
+        logging.info(f"[Notify:finish] Finish of [{self.STEP}]")
 
         if self.is_slack_enabled():
             msg_type = 'success' if success else 'error'
